@@ -29,8 +29,7 @@
 #include "rawspeed/RawSpeed/CameraMetaData.h"
 #include "rawspeed/RawSpeed/ColorFilterArray.h"
 
-extern "C"
-{
+extern "C" {
 #include "imageio.h"
 #include "common/imageio_rawspeed.h"
 #include "common/exif.h"
@@ -40,8 +39,7 @@ extern "C"
 }
 
 // define this function, it is only declared in rawspeed:
-int
-rawspeed_get_number_of_processor_cores()
+int rawspeed_get_number_of_processor_cores()
 {
 #ifdef _OPENMP
   return omp_get_num_procs();
@@ -61,7 +59,7 @@ scale_black_white(uint16_t *const buf, const uint16_t black, const uint16_t whit
 {
   const float scale = 65535.0f/(white-black);
 #ifdef _OPENMP
-  #pragma omp parallel for default(none) schedule(static)
+#pragma omp parallel for default(none) schedule(static)
 #endif
   for(int j=0; j<height; j++)
   {
@@ -75,14 +73,10 @@ scale_black_white(uint16_t *const buf, const uint16_t black, const uint16_t whit
 }
 #endif
 
-dt_imageio_retval_t
-dt_imageio_open_rawspeed(
-  dt_image_t  *img,
-  const char  *filename,
-  dt_mipmap_cache_allocator_t a)
+dt_imageio_retval_t dt_imageio_open_rawspeed(dt_image_t *img, const char *filename,
+                                             dt_mipmap_cache_allocator_t a)
 {
-  if(!img->exif_inited)
-    (void) dt_exif_read(img, filename);
+  if(!img->exif_inited) (void)dt_exif_read(img, filename);
 
 #ifdef __WIN32__
   const size_t len = strlen(filename) + 1;
@@ -90,13 +84,18 @@ dt_imageio_open_rawspeed(
   mbstowcs(filen, filename, len);
   FileReader f(filen);
 #else
-  char filen[1024];
+  char filen[PATH_MAX] = { 0 };
   snprintf(filen, sizeof(filen), "%s", filename);
   FileReader f(filen);
 #endif
 
+#ifdef __APPLE__
   std::auto_ptr<RawDecoder> d;
   std::auto_ptr<FileMap> m;
+#else
+  std::unique_ptr<RawDecoder> d;
+  std::unique_ptr<FileMap> m;
+#endif
 
   try
   {
@@ -106,7 +105,7 @@ dt_imageio_open_rawspeed(
       dt_pthread_mutex_lock(&darktable.plugin_threadsafe);
       if(meta == NULL)
       {
-        char datadir[1024], camfile[1024];
+        char datadir[PATH_MAX] = { 0 }, camfile[PATH_MAX] = { 0 };
         dt_loc_get_datadir(datadir, sizeof(datadir));
         snprintf(camfile, sizeof(camfile), "%s/rawspeed/cameras.xml", datadir);
         // never cleaned up (only when dt closes)
@@ -115,13 +114,20 @@ dt_imageio_open_rawspeed(
       dt_pthread_mutex_unlock(&darktable.plugin_threadsafe);
     }
 
+#ifdef __APPLE__
     m = auto_ptr<FileMap>(f.readFile());
+#else
+    m = unique_ptr<FileMap>(f.readFile());
+#endif
 
     RawParser t(m.get());
-    d = auto_ptr<RawDecoder>(t.getDecoder());
+#ifdef __APPLE__
+    d = auto_ptr<RawDecoder>(t.getDecoder(meta));
+#else
+    d = unique_ptr<RawDecoder>(t.getDecoder(meta));
+#endif
 
-    if(!d.get())
-      return DT_IMAGEIO_FILE_CORRUPTED;
+    if(!d.get()) return DT_IMAGEIO_FILE_CORRUPTED;
 
     d->failOnUnknown = true;
     d->checkSupport(meta);
@@ -133,15 +139,16 @@ dt_imageio_open_rawspeed(
     d.reset();
     m.reset();
 
-    img->filters = 0;
-    if( !r->isCFA )
+    img->filters = 0u;
+    if(!r->isCFA)
     {
       dt_imageio_retval_t ret = dt_imageio_open_rawspeed_sraw(img, r, a);
       return ret;
     }
 
     // only scale colors for sizeof(uint16_t) per pixel, not sizeof(float)
-    // if(r->getDataType() != TYPE_FLOAT32) scale_black_white((uint16_t *)r->getData(), r->blackLevel, r->whitePoint, r->dim.x, r->dim.y, r->pitch/r->getBpp());
+    // if(r->getDataType() != TYPE_FLOAT32) scale_black_white((uint16_t *)r->getData(), r->blackLevel,
+    // r->whitePoint, r->dim.x, r->dim.y, r->pitch/r->getBpp());
     if(r->getDataType() != TYPE_FLOAT32) r->scaleBlackWhite();
     img->bpp = r->getBpp();
     img->filters = r->cfa.getDcrawFilter();
@@ -150,24 +157,41 @@ dt_imageio_open_rawspeed(
       img->flags &= ~DT_IMAGE_LDR;
       img->flags |= DT_IMAGE_RAW;
       if(r->getDataType() == TYPE_FLOAT32) img->flags |= DT_IMAGE_HDR;
+      // special handling for x-trans sensors
+      if(img->filters == 9u)
+      {
+        // get 6x6 CFA offset from top left of cropped image
+        // NOTE: This is different from how things are done with Bayer
+        // sensors. For these, the CFA in cameras.xml is pre-offset
+        // depending on the distance modulo 2 between raw and usable
+        // image data. For X-Trans, the CFA in cameras.xml is
+        // (currently) aligned with the top left of the raw data, and
+        // hence it is shifted here to align with the top left of the
+        // cropped image.
+        iPoint2D tl_margin = r->getCropOffset();
+        for(int i = 0; i < 6; ++i)
+          for(int j = 0; j < 6; ++j)
+            img->xtrans[j][i] = r->cfa.getColorAt((i + tl_margin.x) % 6, (j + tl_margin.y) % 6);
+      }
     }
 
-    // also include used override in orient:
-    const int orientation = dt_image_orientation(img);
-    img->width  = (orientation & 4) ? r->dim.y : r->dim.x;
-    img->height = (orientation & 4) ? r->dim.x : r->dim.y;
+    img->width = r->dim.x;
+    img->height = r->dim.y;
 
-    /* needed in exposure iop for Deflicke */
+    /* needed in exposure iop for Deflicker */
     img->raw_black_level = r->blackLevel;
     img->raw_white_point = r->whitePoint;
 
-    void *buf = dt_mipmap_cache_alloc(img, DT_MIPMAP_FULL, a);
-    if(!buf)
-      return DT_IMAGEIO_CACHE_FULL;
+    img->fuji_rotation_pos = r->metadata.fujiRotationPos;
+    img->pixel_aspect_ratio = (float)r->metadata.pixelAspectRatio;
 
-    dt_imageio_flip_buffers((char *)buf, (char *)r->getData(), r->getBpp(), r->dim.x, r->dim.y, r->dim.x, r->dim.y, r->pitch, orientation);
+    void *buf = dt_mipmap_cache_alloc(img, DT_MIPMAP_FULL, a);
+    if(!buf) return DT_IMAGEIO_CACHE_FULL;
+
+    dt_imageio_flip_buffers((char *)buf, (char *)r->getData(), r->getBpp(), r->dim.x, r->dim.y, r->dim.x,
+                            r->dim.y, r->pitch, ORIENTATION_NONE);
   }
-  catch (const std::exception &exc)
+  catch(const std::exception &exc)
   {
     printf("[rawspeed] %s\n", exc.what());
 
@@ -175,7 +199,7 @@ dt_imageio_open_rawspeed(
      specific ones, consider the file as corrupted */
     return DT_IMAGEIO_FILE_CORRUPTED;
   }
-  catch (...)
+  catch(...)
   {
     printf("Unhandled exception in imageio_rawspeed\n");
     return DT_IMAGEIO_FILE_CORRUPTED;
@@ -184,16 +208,14 @@ dt_imageio_open_rawspeed(
   return DT_IMAGEIO_OK;
 }
 
-dt_imageio_retval_t
-dt_imageio_open_rawspeed_sraw(dt_image_t *img, RawImage r, dt_mipmap_cache_allocator_t a)
+dt_imageio_retval_t dt_imageio_open_rawspeed_sraw(dt_image_t *img, RawImage r, dt_mipmap_cache_allocator_t a)
 {
   // sraw aren't real raw, but not ldr either (need white balance and stuff)
   img->flags &= ~DT_IMAGE_LDR;
   img->flags &= ~DT_IMAGE_RAW;
 
-  const int orientation = dt_image_orientation(img);
-  img->width  = (orientation & 4) ? r->dim.y : r->dim.x;
-  img->height = (orientation & 4) ? r->dim.x : r->dim.y;
+  img->width = r->dim.x;
+  img->height = r->dim.y;
 
   /* needed by Deflicker */
   img->raw_black_level = r->blackLevel;
@@ -202,35 +224,61 @@ dt_imageio_open_rawspeed_sraw(dt_image_t *img, RawImage r, dt_mipmap_cache_alloc
   size_t raw_width = r->dim.x;
   size_t raw_height = r->dim.y;
 
+  iPoint2D dimUncropped = r->getUncroppedDim();
+  iPoint2D cropTL = r->getCropOffset();
+
   // work around 50D bug
   char makermodel[1024];
   dt_colorspaces_get_makermodel(makermodel, sizeof(makermodel), img->exif_maker, img->exif_model);
 
   // actually we want to store full floats here:
-  img->bpp = 4*sizeof(float);
+  img->bpp = 4 * sizeof(float);
+  img->cpp = r->getCpp();
   void *buf = dt_mipmap_cache_alloc(img, DT_MIPMAP_FULL, a);
-  if(!buf)
-    return DT_IMAGEIO_CACHE_FULL;
+  if(!buf) return DT_IMAGEIO_CACHE_FULL;
 
   int black = r->blackLevel;
   int white = r->whitePoint;
 
-  ushort16* raw_img = (ushort16*)r->getData();
+  uint16_t *raw_img = (uint16_t *)r->getDataUncropped(0, 0);
 
-#if 0
-  dt_imageio_flip_buffers_ui16_to_float(buf, raw_img, black, white, 3, raw_width, raw_height,
-                                        raw_width, raw_height, raw_width + raw_width_extra, orientation);
-#else
+  const float scale = (float)(white - black);
 
-  // TODO - OMPize this.
-  float scale = 1.0 / (white - black);
-  for( size_t row = 0; row < raw_height; ++row )
-    for( size_t col = 0; col < raw_width; ++col )
-      for( int k = 0; k < 3; ++k )
-        ((float *)buf)[4 * dt_imageio_write_pos(col, row, raw_width, raw_height, raw_width, raw_height, orientation) + k] =
-          // ((float)raw_img[row*(raw_width + raw_width_extra)*3 + col*3 + k] - black) * scale;
-          ((float)raw_img[row*(r->pitch/2) + col*3 + k] - black) * scale;
+#ifdef _OPENMP
+#pragma omp parallel for default(none) schedule(static) shared(raw_width, raw_height, raw_img, img,          \
+                                                               dimUncropped, cropTL, buf, black)
 #endif
+  for(size_t row = 0; row < raw_height; row++)
+  {
+    const uint16_t *in = ((uint16_t *)raw_img)
+                         + (size_t)(img->cpp * (dimUncropped.x * (row + cropTL.y) + cropTL.x));
+    float *out = ((float *)buf) + (size_t)4 * row * raw_width;
+
+    for(size_t col = 0; col < raw_width; col++, in += img->cpp, out += 4)
+    {
+      for(int k = 0; k < 3; k++)
+      {
+        if(img->cpp == 1)
+        {
+          /*
+           * monochrome image (e.g. Leica M9 monochrom),
+           * we need to copy data from only channel to each of 3 channels
+           */
+
+          out[k] = MAX(0.0f, (((float)(*in)) - black) / scale);
+        }
+        else
+        {
+          /*
+           * standard 3-ch image
+           * just copy 3 ch to 3 ch
+           */
+
+          out[k] = MAX(0.0f, (((float)(in[k])) - black) / scale);
+        }
+      }
+    }
+  }
 
   return DT_IMAGEIO_OK;
 }
