@@ -25,6 +25,11 @@
 
 #define DT_GUI_IOP_MODULE_CONTROL_SPACING 2
 
+/* helper macro that applies the DPI transformation to fixed pixel values. input should be defaulting to 96
+ * DPI */
+#define DT_PIXEL_APPLY_DPI(value) (value * darktable.gui->dpi_factor)
+#define DT_PIXEL_APPLY_PPI(value) (value * darktable.gui->dpi_factor * darktable.gui->ppd)
+
 typedef enum dt_gui_view_switch_t
 {
   DT_GUI_VIEW_SWITCH_TO_TETHERING = 1,
@@ -32,8 +37,7 @@ typedef enum dt_gui_view_switch_t
   DT_GUI_VIEW_SWITCH_TO_DARKROOM,
   DT_GUI_VIEW_SWITCH_TO_MAP,
   DT_GUI_VIEW_SWITCH_TO_SLIDESHOW
-}
-dt_gui_view_switch_to_t;
+} dt_gui_view_switch_to_t;
 
 typedef struct dt_gui_widgets_t
 {
@@ -45,11 +49,10 @@ typedef struct dt_gui_widgets_t
   GtkWidget *top_border;
 
   /* left panel */
-  GtkTable *panel_left;                 // panel table 3 rows, top,center,bottom and file on center
+  GtkTable *panel_left; // panel table 3 rows, top,center,bottom and file on center
   GtkTable *panel_right;
 
-}
-dt_gui_widgets_t;
+} dt_gui_widgets_t;
 
 typedef struct dt_gui_gtk_t
 {
@@ -70,12 +73,40 @@ typedef struct dt_gui_gtk_t
   gboolean grouping;
   int32_t expanded_group_id;
 
-  double dpi;
+  gboolean show_overlays;
+
+  double dpi, dpi_factor, ppd;
 
   // store which gtkrc we loaded:
-  char gtkrc[DT_MAX_PATH_LEN];
+  char gtkrc[PATH_MAX];
+} dt_gui_gtk_t;
+
+#if (CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 14, 0))
+inline cairo_surface_t *dt_cairo_image_surface_create(cairo_format_t format, int width, int height) {
+  cairo_surface_t *cst = cairo_image_surface_create(format, width * darktable.gui->ppd, height * darktable.gui->ppd);
+  cairo_surface_set_device_scale(cst, darktable.gui->ppd, darktable.gui->ppd);
+  return cst;
 }
-dt_gui_gtk_t;
+
+inline cairo_surface_t *dt_cairo_image_surface_create_for_data(unsigned char *data, cairo_format_t format, int width, int height, int stride) {
+  cairo_surface_t *cst = cairo_image_surface_create_for_data(data, format, width, height, stride);
+  cairo_surface_set_device_scale(cst, darktable.gui->ppd, darktable.gui->ppd);
+  return cst;
+}
+
+inline int dt_cairo_image_surface_get_width(cairo_surface_t *surface) {
+  return cairo_image_surface_get_width(surface) / darktable.gui->ppd;
+}
+
+inline int dt_cairo_image_surface_get_height(cairo_surface_t *surface) {
+  return cairo_image_surface_get_height(surface) / darktable.gui->ppd;
+}
+#else
+#define dt_cairo_image_surface_create cairo_image_surface_create
+#define dt_cairo_image_surface_create_for_data cairo_image_surface_create_for_data
+#define dt_cairo_image_surface_get_width cairo_image_surface_get_width
+#define dt_cairo_image_surface_get_height cairo_image_surface_get_height
+#endif
 
 int dt_gui_gtk_init(dt_gui_gtk_t *gui, int argc, char *argv[]);
 void dt_gui_gtk_run(dt_gui_gtk_t *gui);
@@ -144,8 +175,7 @@ typedef enum dt_ui_container_t
 
   /* Count of containers */
   DT_UI_CONTAINER_SIZE
-}
-dt_ui_container_t;
+} dt_ui_container_t;
 
 typedef enum dt_ui_panel_t
 {
@@ -186,13 +216,15 @@ void dt_ui_container_focus_widget(struct dt_ui_t *ui, const dt_ui_container_t c,
 /** \brief removes all child widgets from container */
 void dt_ui_container_clear(struct dt_ui_t *ui, const dt_ui_container_t c);
 /** \brief shows/hide a panel */
-void dt_ui_panel_show(struct dt_ui_t *ui,const dt_ui_panel_t, gboolean show);
+void dt_ui_panel_show(struct dt_ui_t *ui, const dt_ui_panel_t, gboolean show, gboolean write);
+/** show or hide outermost borders with expand arrows */
+void dt_ui_border_show(struct dt_ui_t *ui, gboolean show);
 /** \brief restore saved state of panel visibility for current view */
 void dt_ui_restore_panels(struct dt_ui_t *ui);
 /** \brief toggle view of panels eg. collaps/expands to previous view state */
 void dt_ui_toggle_panels_visibility(struct dt_ui_t *ui);
 /** \brief get visible state of panel */
-gboolean dt_ui_panel_visible(struct dt_ui_t *ui,const dt_ui_panel_t);
+gboolean dt_ui_panel_visible(struct dt_ui_t *ui, const dt_ui_panel_t);
 /** \brief get the center drawable widget */
 GtkWidget *dt_ui_center(struct dt_ui_t *ui);
 /** \brief get the main window widget */
